Read-only snapshots of canonical knowledge-base repository resources.
Loading verifies repository structure and YAML deserialization, but does not perform generic or domain semantic validation.
Structs
- Repository
Snapshot - A complete, immutable, structurally valid view of a knowledge-base repository.
Enums
- Error
- An error loading a structured repository resource.